# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.5](https://github.com/conda/rattler/compare/file_url-v0.1.4...file_url-v0.1.5) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.1.4](https://github.com/conda/rattler/compare/file_url-v0.1.3...file_url-v0.1.4) - 2024-08-15

### Fixed
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))

## [0.1.3](https://github.com/conda/rattler/compare/file_url-v0.1.2...file_url-v0.1.3) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.1.2](https://github.com/baszalmstra/rattler/compare/file_url-v0.1.1...file_url-v0.1.2) - 2024-06-04

### Added
- parse url and path as matchspec ([#704](https://github.com/baszalmstra/rattler/pull/704))

## [0.1.1](https://github.com/conda/rattler/compare/file_url-v0.1.0...file_url-v0.1.1) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))
